@@ -22,9 +22,36 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-from .graphs import IPFPath
-from .parameters import Unicast, Multicast, Options, Algorithm
+from ipfabric_diagrams.input_models.constants import VALID_NET_PROTOCOLS, VALID_PATH_PROTOCOLS
+from ipfabric_diagrams.input_models.graph_parameters import (
+    Unicast,
+    Multicast,
+    Host2GW,
+    Network,
+    OtherOptions,
+    Algorithm,
+    EntryPoint,
+    Layout,
+)
+from ipfabric_diagrams.input_models.graph_settings import NetworkSettings, PathLookupSettings, Overlay
+from .graphs import IPFDiagram
 
-__all__ = ["IPFPath", "Unicast", "Multicast", "Options", "Algorithm", "icmp"]
+__all__ = [
+    "IPFDiagram",
+    "Unicast",
+    "Multicast",
+    "Host2GW",
+    "Network",
+    "OtherOptions",
+    "Algorithm",
+    "Overlay",
+    "icmp",
+    "NetworkSettings",
+    "PathLookupSettings",
+    "EntryPoint",
+    "VALID_NET_PROTOCOLS",
+    "VALID_PATH_PROTOCOLS",
+    "Layout",
+]
 
-__version__ = "1.0.4"
+__version__ = "1.1.1"
